#  tests for types-protobuf-4.23.0.1-py39hca03da5_0 (this is a generated file);
print('===== testing package: types-protobuf-4.23.0.1-py39hca03da5_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
# HACK: from __future__ import annotations must be the first line, but conda build injects print statements. 
import _run_test#  --- run_test.py (end) ---

print('===== types-protobuf-4.23.0.1-py39hca03da5_0 OK =====');
